pub struct MockGitLabApi { /* private fields */ }Expand description
The GitLab operations this crate exposes — the interface consumers code
against and mock in tests. The lean MR lifecycle; reach unmodelled glab
commands through run.
Implementations
Sourceimpl MockGitLabApi
impl MockGitLabApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockGitLabApi
impl MockGitLabApi
Sourcepub fn expect_run(&mut self) -> &mut Expectation
pub fn expect_run(&mut self) -> &mut Expectation
Create an Expectation for mocking the run method
Sourcepub fn expect_run_raw(&mut self) -> &mut Expectation
pub fn expect_run_raw(&mut self) -> &mut Expectation
Create an Expectation for mocking the run_raw method
Sourcepub fn expect_version(&mut self) -> &mut Expectation
pub fn expect_version(&mut self) -> &mut Expectation
Create an Expectation for mocking the version method
Sourcepub fn expect_auth_status(&mut self) -> &mut Expectation
pub fn expect_auth_status(&mut self) -> &mut Expectation
Create an Expectation for mocking the auth_status method
Sourcepub fn expect_repo_view(&mut self) -> &mut Expectation
pub fn expect_repo_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the repo_view method
Sourcepub fn expect_mr_list(&mut self) -> &mut Expectation
pub fn expect_mr_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_list method
Sourcepub fn expect_mr_view(&mut self) -> &mut Expectation
pub fn expect_mr_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_view method
Sourcepub fn expect_mr_create(&mut self) -> &mut Expectation
pub fn expect_mr_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_create method
Sourcepub fn expect_mr_merge(&mut self) -> &mut Expectation
pub fn expect_mr_merge(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_merge method
Sourcepub fn expect_mr_ready(&mut self) -> &mut Expectation
pub fn expect_mr_ready(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_ready method
Sourcepub fn expect_mr_close(&mut self) -> &mut Expectation
pub fn expect_mr_close(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_close method
Sourcepub fn expect_mr_checks(&mut self) -> &mut Expectation
pub fn expect_mr_checks(&mut self) -> &mut Expectation
Create an Expectation for mocking the mr_checks method
Sourcepub fn expect_issue_list(&mut self) -> &mut Expectation
pub fn expect_issue_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_list method
Sourcepub fn expect_issue_view(&mut self) -> &mut Expectation
pub fn expect_issue_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_view method
Sourcepub fn expect_issue_create(&mut self) -> &mut Expectation
pub fn expect_issue_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_create method
Sourcepub fn expect_release_list(&mut self) -> &mut Expectation
pub fn expect_release_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the release_list method
Sourcepub fn expect_release_view(&mut self) -> &mut Expectation
pub fn expect_release_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the release_view method